@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.542-6-g930d4020
+package JSON::Schema::Modern; # git description: v0.543-3-ga802bc0b
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema data validation structure specification
 
-our $VERSION = '0.543';
+our $VERSION = '0.544';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -163,8 +163,7 @@ sub add_schema {
       errors => [ $document->errors ],
       exception => 1,
     );
-    die $result if (caller())[0]->isa(__PACKAGE__);
-    croak $result.'';
+    die $result;
   }
 
   if (not grep refaddr($_->{document}) == refaddr($document), $self->_canonical_resources) {
@@ -249,6 +248,7 @@ sub traverse ($self, $schema_reference, $config_override = {}) {
     configs => {},
     callbacks => $config_override->{callbacks} // {},
     evaluator => $self,
+    traverse => 1,
   };
 
   try {
@@ -291,6 +291,7 @@ sub traverse ($self, $schema_reference, $config_override = {}) {
     }
   }
 
+  delete $state->{traverse};
   return $state;
 }
 
@@ -460,7 +461,7 @@ sub _traverse_subschema ($self, $schema, $state) {
   delete $state->{keyword};
 
   if ($self->strict and keys %unknown_keywords) {
-    abort($state, 'unknown keyword%s found: %s', keys %unknown_keywords > 1 ? 's' : '',
+    ()= E($state, 'unknown keyword%s found: %s', keys %unknown_keywords > 1 ? 's' : '',
       join(', ', sort keys %unknown_keywords));
   }
 
@@ -951,7 +952,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.543
+version 0.544
 
 =head1 SYNOPSIS
 
